2.1.2 (August 8, 2016)
~~~~~~~~~~~~~~~~~~~~~~

- Fixed a bug when logging http requests.
- Create default log handlers if user hasn't configured any.

2.1.1 (July 22, 2016)
~~~~~~~~~~~~~~~~~~~~~

- More flexible configuration of requests in `HTTPServer
  <https://jsonrpcclient.readthedocs.io/en/latest/http.html#configuration>`_.
